@@ -47,7 +47,7 @@ class Memory(checks.AgentCheck):
                    float(100 - swap_info.percent),
                    dimensions=dimensions)
 
-        count = 8
+        count = 9
         if hasattr(mem_info, 'buffers') and mem_info.buffers:
             self.gauge('mem.used_buffers',
                        int(mem_info.buffers / 1048576),
@@ -60,6 +60,20 @@ class Memory(checks.AgentCheck):
                        dimensions=dimensions)
             count += 1
 
+        if (hasattr(mem_info, 'buffers') and mem_info.buffers and
+           hasattr(mem_info, 'cached') and mem_info.cached):
+
+            mem_used_real = mem_info.used
+            if psutil.version_info < (4, 4, 0):
+                #
+                # pusutil versions prior to 4.4.0 didn't subtract buffers and
+                # cache, but starting in 4.4.0 psutil does.
+                #
+                mem_used_real = mem_used_real - mem_info.buffers - mem_info.cached
+            self.gauge('mem.used_real_mb', int(mem_used_real / 1048576),
+                       dimensions=dimensions)
+            count += 1
+
         if hasattr(mem_info, 'shared') and mem_info.shared:
             self.gauge('mem.used_shared',
                        int(mem_info.shared / 1048576),
