@@ -9,7 +9,7 @@
 """
 
 
-#    (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+#    (C) Copyright 2015,2016 Hewlett Packard Enterprise Development Company LP
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -26,6 +26,7 @@
 import re
 import socket
 import sys
+import time
 
 from monasca_agent.collector.checks import AgentCheck
 
@@ -38,12 +39,6 @@ class WrapMK(AgentCheck):
     def __init__(self, name, init_config, agent_config, instances=None):
         AgentCheck.__init__(self, name, init_config, agent_config, instances)
 
-    def _create_status_event(self, status, msg, instance):
-        """Does nothing: status events are not yet supported by Mon API.
-
-        """
-        return
-
     def check(self, instance):
         """Run the display_name and capture the result.
 
