@@ -20,6 +20,7 @@ import traceback
 import uuid
 
 import logging
+import logging.handlers
 
 from numbers import Number
 
@@ -615,7 +616,6 @@ def initialize_logging(logger_name):
         if logging_config['log_to_syslog']:
             try:
                 syslog_format = '%s[%%(process)d]: %%(levelname)s (%%(filename)s:%%(lineno)s): %%(message)s' % logger_name
-                from logging.handlers import SysLogHandler
 
                 if logging_config['syslog_host'] is not None and logging_config[
                         'syslog_port'] is not None:
@@ -626,7 +626,8 @@ def initialize_logging(logger_name):
                     if sys.platform == 'darwin':
                         sys_log_addr = "/var/run/syslog"
 
-                handler = SysLogHandler(address=sys_log_addr, facility=SysLogHandler.LOG_DAEMON)
+                handler = logging.handlers.SysLogHandler(
+                    address=sys_log_addr, facility=logging.handlers.SysLogHandler.LOG_DAEMON)
                 handler.setFormatter(
                     logging.Formatter(syslog_format, log_date_format))
                 root_log = logging.getLogger()
