@@ -48,7 +48,7 @@ class RabbitMQ(monasca_setup.detection.Plugin):
     def _detect(self):
         """Run detection, set self.available True if the service is detected.
         """
-        if monasca_setup.detection.find_process_service('rabbitmq-server') is not None:
+        if monasca_setup.detection.find_process_service('rabbitmq-server'):
             self.available = True
 
     def _get_config(self):
