@@ -8,9 +8,12 @@ import psutil
 import re
 import unittest
 
+from oslo_config import cfg
+
 from mock import patch
 from mock.mock import MagicMock
 
+from monasca_setup.detection import utils
 from monasca_setup.detection.plugins.ovs import Ovs
 
 
@@ -38,7 +41,7 @@ class TestOvs(unittest.TestCase):
         unittest.TestCase.setUp(self)
         with patch.object(Ovs, '_detect') as mock_detect:
             self.ovs_obj = Ovs('temp_dir')
-            self.has_option = [True, True, True, False, False, True]
+            self.has_option = [False, True]
             self.get_value = [MagicMock(), MagicMock(), MagicMock(),
                               'http://10.10.10.10', 'region1']
             self.assertTrue(mock_detect.called)
@@ -47,6 +50,7 @@ class TestOvs(unittest.TestCase):
         ovs_obj.neutron_conf = None
         ovs_obj.available = False
         with contextlib.nested(
+                patch.object(cfg, 'CONF'),
                 patch.object(psutil, 'process_iter',
                              return_value=[ps_util_get_proc()]),
                 patch.object(os.path, 'isfile', return_value=True),
@@ -54,22 +58,28 @@ class TestOvs(unittest.TestCase):
                              return_value=True),
                 patch.object(ovs_obj, '_is_neutron_conf_valid',
                              return_value=file_config_valid)) as (
-                mock_process_iter, mock_isfile, dependencies, _):
+                                     mock_conf, mock_process_iter,
+                                     mock_isfile, dependencies, _):
             ovs_obj._detect()
             self.assertTrue(mock_process_iter.called)
             if not ps_util_get_proc.cmdLine:
                 self.assertFalse(mock_isfile.called)
 
     def _build_config(self, ovs_obj, dependencies_installed=True):
+        ovs_obj.conf = MagicMock()
+        ovs_obj.conf.default_config_files = ovs_obj.neutron_conf
+        ovs_obj.conf.default_config_dirs = os.path.abspath(os.path.join(ovs_obj.neutron_conf, os.pardir))
         with patch.object(ConfigParser, 'SafeConfigParser') as mock_config_parser:
             config_parser_obj = mock_config_parser.return_value
             with contextlib.nested(
+                    patch.object(cfg, 'CONF'),
                     patch.object(LOG, 'info'),
-                    patch.object(config_parser_obj, 'has_option',
-                                 side_effect=self.has_option),
-                    patch.object(config_parser_obj, 'get',
-                                 side_effect=self.get_value)) as (
-                         mock_log_info, mock_has_option, mock_get):
+                    patch.object(ovs_obj, 'has_option',
+                                     side_effect=self.has_option),
+                    patch.object(ovs_obj, 'get_option',
+                                     side_effect=self.get_value)) as (
+                                             mock_conf, mock_log_info,
+                                             mock_has_option, mock_get):
                 result = ovs_obj.build_config()
                 if dependencies_installed:
                     self.assertTrue(mock_log_info.called)
@@ -88,14 +98,14 @@ class TestOvs(unittest.TestCase):
             self.assertEqual(result['ovs']['init_config']['neutron_refresh'],
                              13000)
             self.assertFalse(result['ovs']['init_config']['network_use_bits'])
-            self.assertIsInstance(result['ovs']['init_config']['admin_user'],
+            self.assertIsInstance(result['ovs']['init_config']['username'],
                                   MagicMock)
-            self.assertIsInstance(result['ovs']['init_config']['admin_password'],
+            self.assertIsInstance(result['ovs']['init_config']['password'],
                                   MagicMock)
-            self.assertIsInstance(result['ovs']['init_config']['admin_tenant_name'],
+            self.assertIsInstance(result['ovs']['init_config']['project_name'],
                                   MagicMock)
-            self.assertEqual(result['ovs']['init_config']['identity_uri'],
-                             'http://10.10.10.10/v2.0')
+            self.assertEqual(result['ovs']['init_config']['auth_url'],
+                             'http://10.10.10.10')
             self.assertEqual(result['ovs']['init_config']['region_name'],
                              'region1')
             self.assertEqual(result['ovs']['init_config']['cache_dir'],
@@ -118,11 +128,11 @@ class TestOvs(unittest.TestCase):
                          "sudo /usr/bin/ovs-vsctl")
         self.assertEqual(result['ovs']['init_config']['included_interface_re'],
                          'qg.*|vhu.*|sg.*')
-        self.assertIsInstance(result['ovs']['init_config']['admin_user'],
+        self.assertIsInstance(result['ovs']['init_config']['username'],
                               MagicMock)
-        self.assertIsInstance(result['ovs']['init_config']['admin_password'],
+        self.assertIsInstance(result['ovs']['init_config']['password'],
                               MagicMock)
-        self.assertIsInstance(result['ovs']['init_config']['admin_tenant_name'],
+        self.assertIsInstance(result['ovs']['init_config']['project_name'],
                               MagicMock)
         self.assertTrue(result['ovs']['init_config']['use_absolute_metrics'])
         self.assertTrue(result['ovs']['init_config']['use_rate_metrics'])
@@ -130,10 +140,11 @@ class TestOvs(unittest.TestCase):
         return result
 
     def test_detect(self):
-        self._detect(self.ovs_obj)
-        self.assertTrue(self.ovs_obj.available)
-        self.assertEqual(self.ovs_obj.neutron_conf,
-                         '/etc/neutron/neutron.conf')
+        with patch.object(utils, 'load_oslo_configuration'):
+            self._detect(self.ovs_obj)
+            self.assertTrue(self.ovs_obj.available)
+            self.assertEqual(self.ovs_obj.neutron_conf,
+                             '/etc/neutron/neutron.conf')
 
     def test_detect_invalid_config_file(self):
         self._detect(self.ovs_obj, file_config_valid=False)
@@ -142,9 +153,10 @@ class TestOvs(unittest.TestCase):
 
     def test_detect_devstack(self):
         ps_util_get_proc.cmdLine = ['--config-file=/opt/stack/neutron.conf']
-        self._detect(self.ovs_obj)
-        self.assertTrue(self.ovs_obj.available)
-        self.assertEqual(self.ovs_obj.neutron_conf, '/opt/stack/neutron.conf')
+        with patch.object(utils, 'load_oslo_configuration'):
+            self._detect(self.ovs_obj)
+            self.assertTrue(self.ovs_obj.available)
+            self.assertEqual(self.ovs_obj.neutron_conf, '/opt/stack/neutron.conf')
 
     def test_detect_warning(self):
         with patch.object(LOG, 'error') as mock_log_warn:
@@ -158,6 +170,7 @@ class TestOvs(unittest.TestCase):
         self.ovs_obj.neutron_conf = None
         self.ovs_obj.args = {'conf_file_path': '/opt/stack/neutron.conf'}
         with contextlib.nested(
+                patch.object(utils, 'load_oslo_configuration'),
                 patch.object(psutil, 'process_iter',
                              return_value=[ps_util_get_proc()]),
                 patch.object(os.path, 'isfile', return_value=True),
@@ -165,7 +178,8 @@ class TestOvs(unittest.TestCase):
                              return_value=True),
                 patch.object(self.ovs_obj, '_is_neutron_conf_valid',
                              return_value=True)) as (
-                mock_process_iter, mock_isfile, dependencies, _):
+                                     mock_conf, mock_process_iter,
+                                     mock_isfile, dependencies, _):
             self.ovs_obj._detect()
             self.assertTrue(mock_isfile.called)
             self.assertTrue(self.ovs_obj.available)
@@ -179,10 +193,10 @@ class TestOvs(unittest.TestCase):
     def test_build_config_with_args(self):
         with patch.object(LOG, 'warn') as mock_log_warn:
             self.ovs_obj.neutron_conf = 'neutron-conf'
-            self.ovs_obj.args = {'admin_user': 'admin',
-                                 'admin_password': 'password',
-                                 'admin_tenant_name': 'tenant',
-                                 'identity_uri': '10.10.10.20',
+            self.ovs_obj.args = {'username': 'admin',
+                                 'password': 'password',
+                                 'project_name': 'tenant',
+                                 'auth_url': '10.10.10.20',
                                  'region_name': 'region0',
                                  'neutron_refresh': 13000,
                                  'use_absolute_metrics': False}
@@ -199,10 +213,10 @@ class TestOvs(unittest.TestCase):
     def test_build_config_invalid_arg_warning(self):
         with patch.object(LOG, 'warn') as mock_log_warn:
             self.ovs_obj.neutron_conf = 'neutron-conf'
-            self.ovs_obj.args = {'admin_user': 'admin',
-                                 'admin_password': 'password',
-                                 'admin_tenant_name': 'tenant',
-                                 'identity_uri': '10.10.10.20',
+            self.ovs_obj.args = {'username': 'admin',
+                                 'password': 'password',
+                                 'project_name': 'tenant',
+                                 'auth_url': '10.10.10.20',
                                  'region_name': 'region0',
                                  'neutron_refresh': 13000,
                                  'use_absolute_metrics': False,
@@ -215,32 +229,32 @@ class TestOvs(unittest.TestCase):
 
     def test_build_config_if_auth_version(self):
         self.ovs_obj.neutron_conf = 'neutron-conf'
-        self.has_option = [True, True, True, True, True, True]
+        self.has_option = [True, True]
         self.get_value = [MagicMock(), MagicMock(), MagicMock(),
-                          'v3.0', 'http://10.10.10.10',
+                          'http://10.10.10.10',
                           'http://10.10.10.10', 'region1']
         result = self._build_config_without_args(self.ovs_obj)
-        self.assertEqual(result['ovs']['init_config']['identity_uri'],
-                         'http://10.10.10.10/v3.0')
+        self.assertEqual(result['ovs']['init_config']['auth_url'],
+                         'http://10.10.10.10')
 
     def test_build_config_if_auth_url_has_version(self):
         self.ovs_obj.neutron_conf = 'neutron-conf'
-        self.has_option = [True, True, True, True, True, True]
+        self.has_option = [True, True]
         self.get_value = [MagicMock(), MagicMock(), MagicMock(),
-                          'v3.0', 'http://10.10.10.10/v1',
+                          'http://10.10.10.10/v1',
                           'http://10.10.10.10/v1', 'region1']
         result = self._build_config_without_args(self.ovs_obj)
-        self.assertEqual(result['ovs']['init_config']['identity_uri'],
-                         'http://10.10.10.10/v1/')
+        self.assertEqual(result['ovs']['init_config']['auth_url'],
+                         'http://10.10.10.10/v1')
 
     def test_build_config_region_name_from_nova(self):
         self.ovs_obj.neutron_conf = 'neutron-conf'
-        self.has_option = [True, True, True, False, False, False]
+        self.has_option = [False, False]
         self.get_value = [MagicMock(), MagicMock(), MagicMock(),
                           'http://10.10.10.10', 'region2']
         result = self._build_config_without_args(self.ovs_obj)
-        self.assertEqual(result['ovs']['init_config']['identity_uri'],
-                         'http://10.10.10.10/v2.0')
+        self.assertEqual(result['ovs']['init_config']['auth_url'],
+                         'http://10.10.10.10')
         self.assertEqual(result['ovs']['init_config']['region_name'],
                          'region2')
 
